@@ -117,7 +117,7 @@ comp <- function(x, ...) UseMethod("comp")
 #' \cr \cr
 #' Then calculate:
 #' \deqn{ Q = \frac{ \sup{|Z(t)|}}{\sigma(\tau)}, \quad t<\tau }{
-#' Q = sup( |Z(t)| ) / sigma(tau), t<tau}
+#'        Q = sup( |Z(t)| ) / sigma(tau), t < tau}
 #' When the null hypothesis is true,
 #' the distribution of \eqn{Q} is approximately
 #'  \deqn{Q \sim \sup{|B(x)|, \quad 0 \leq x \leq 1}}{
@@ -126,7 +126,7 @@ comp <- function(x, ...) UseMethod("comp")
 #'  \deqn{Pr[\sup|B(t)|>x] = 1 - \frac{4}{\pi}
 #'                           \sum_{k=0}^{\infty}
 #'                           \frac{(- 1)^k}{2k + 1} \exp{\frac{-\pi^2(2k + 1)^2}{8x^2}}}{
-#'        Pr[sup|B(t)|>x] = 1 - 4/pi sum((-1)^k / (2 * k + 1) * exp(-pi^2 (2k + 1)^2 / x^2))}
+#'        Pr[sup|B(t)| > x] = 1 - 4 / pi sum((-1)^k / (2 * k + 1) * exp(-pi^2 (2k + 1)^2 / x^2))}
 #' \bold{Tests for trend} are designed to detect ordered differences in survival curves.
 #' \cr
 #' That is, for at least one group:
@@ -196,6 +196,9 @@ comp <- function(x, ...) UseMethod("comp")
 #' 
 #' @examples
 #' ## Two covariate groups
+#' data("leukemia", package="survival")
+#' f1 <- survfit(Surv(time, status) ~ x, data=leukemia)
+#' comp(ten(f1))
 #' ## K&M 2nd ed. Example 7.2, Table 7.2, pp 209--210.
 #' data("kidney", package="KMsurv")
 #' t1 <- ten(Surv(time=time, event=delta) ~ type, data=kidney)
@@ -301,7 +304,7 @@ comp.ten <- function(x,
     if (ncg1==2) {
 ### log-rank family
         ## make observed - expected for one group
-        eMP1 <- unlist(eMP1[, .SD, .SDcols=length(eMP1)])
+        eMP1 <- unlist(eMP1[, .SD, .SDcols=(length(eMP1) - 1L)])
         data.table::set(res1, j="Q",
                         value=colSums(wt1 * eMP1))
         data.table::set(res1, j="Var",
